/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.service.solr;

import java.util.Date;

import org.joda.time.DateTime;
import org.joda.time.DateTimeZone;
import org.joda.time.format.DateTimeFormatter;
import org.joda.time.format.ISODateTimeFormat;

/**
 * @author anders
 * 
 */
public class DateFormatter {

    public enum DateFormat {
        SOLR_DATE_FORMAT(ISODateTimeFormat.dateTime()), W3CDTF(ISODateTimeFormat.dateTimeNoMillis()), TIME_ONLY(
                ISODateTimeFormat.hourMinuteSecond()), DATE_ONLY(ISODateTimeFormat.yearMonthDay());
        DateTimeFormatter formatter;

        DateFormat(DateTimeFormatter formatter) {
            this.formatter = formatter;
        }

        public DateTimeFormatter formatter() {
            return formatter;
        }
    }

    public static String format(int year, final int month, final int date, final DateFormat dateFormat) {
        DateTime dt = new DateTime(year, month, date, 0, 0, 0, 0, DateTimeZone.UTC);
        return dt.toString(dateFormat.formatter);
    }

    public static Date parse(final String dateString, final DateFormat format) {
        return format.formatter.parseDateTime(dateString).toDate();
    }

    public static String format(final Date date, final DateFormat dateFormat) {
        DateTime dt = new DateTime(date.getTime(), DateTimeZone.UTC);
        return dt.toString(dateFormat.formatter);
    }

    public static boolean validate(final String solrDateString, final DateFormat dateFormat) {
        try {
            dateFormat.formatter.parseDateTime(solrDateString);
        } catch (UnsupportedOperationException e) {
            return false;
        } catch (IllegalArgumentException e) {
            return false;
        }
        return true;
    }

    public static void main(String[] args) {
        DateTime dt = new DateTime(new Date().getTime(), DateTimeZone.UTC);
        System.out.println(dt.toString(ISODateTimeFormat.dateTime()));
    }
}
