/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.ifeed.service.solr;

import org.apache.commons.lang.ArrayUtils;
import org.apache.commons.lang.StringUtils;

/**
 * @author anders
 *
 */
public class SolrQueryEscaper {
    private static final char ESCAPE_CHAR = '\\';
    private static final char[] SPECIAL_CHARACTERS = {'+', '-', '!',
            '(', ')', '{', '}', '[', ']', '^', '\'', '~', '*', '?', ':', '\\'};
    private static final String[] SPECIAL_CHAR_PAIR = {"&&", "||"};
    private static final String[] SPECIAL_CHAR_PAIR_ESCAPED = {"\\&&", "\\||"};

    public static String escape(String query) {
        StringBuilder sb = new StringBuilder(query.length());

        for (char ch : query.toCharArray()) {
            if (isSpecialCharacter(ch)) {
                sb.append(ESCAPE_CHAR);
            }
            sb.append(ch);
        }
        String escapedQuery = sb.toString();
        return StringUtils.replaceEach(escapedQuery, SPECIAL_CHAR_PAIR,
                SPECIAL_CHAR_PAIR_ESCAPED);
    }


    private static boolean isSpecialCharacter(char ch) {
        return ArrayUtils.contains(SPECIAL_CHARACTERS, ch);
    }
}
